# 🚀 programmering.no | 🤓 matematikk.as
# S1 - Eksamen - 2023 Høst (Torodd)
# Oppgave 3 b) Sparekonto - Påstand: Dobbelt så lang tid 

from sympy import Symbol, Eq, Reals, solveset

# Påstand
# Det vil gå nøyaktig dobbelt så lang tid før beløpet Per har på konto,
# har dobla seg, som det vil gå før beløpet Kåre har på konto, har dobla seg.
#
# Argumenter for at påstanden ikkje er riktig.
# Dersom dette stemmer må 1.03^2x og 1.06^x vera det same.
# 1.03^2x = (1.03^2)^x = 1.0609^x ≠ 1.06^x
#
# Påstanden er ikkje riktig.
