# 🚀 programmering.no | 🤓 matematikk.as
# - Eksempel på range (intervall) med kun øvre grense

# Variabler
intervall = range(10)

# Merk at øvre grense 10 ikke er inkludert
for tall in intervall:
    print(tall)
