# 🚀 programmering.no | 🤓 matematikk.as
# - Type casting fra string til integer

# Variabler
tall_1 = 60
tall_2 = "40"

# For å regne med tall_2, så må tallet type castes fra str til int
sum = tall_1 + int(tall_2)

# Print
print(sum)
