# 🚀 programmering.no | 🤓 matematikk.as
# - Finn antall bokstaver (char) med len()

# Variabler
hei      = "Hei, Python 🐍"
char_ant = len(hei)

# Print
print(f"String: {hei}")
print(f"Antall chars: {char_ant}")
